@@ -1,6 +1,6 @@
 auth_sucess <- tryCatch(
-  cancerscreening:::khis_cred_testing(),
-  cancerscreening_cred_internal_error = function(e) NULL
+  khisr:::khis_cred_testing(),
+  khis_cred_internal_error = function(e) NULL
 )
 if(!isTRUE(auth_sucess)) {
   cancerscreening:::cancerscreening_bullets(c(
@@ -10,5 +10,5 @@ if(!isTRUE(auth_sucess)) {
 }
 
 skip_if_no_cred <- function() {
-  testthat::skip_if_not(khis_has_cred(), "No KHIS credentials")
+  testthat::skip_if_not(khisr::khis_has_cred(), "No KHIS credentials")
 }
